==> gnustep-base_1.24.7.orig.tar.gz: gnustep-base-1.24.7/Source/Additions/unicode/cop.h <==
/* COP table */
/*
  Copyright (C) 2005 Free Software Foundation

  Copying and distribution of this file, with or without modification,
  are permitted in any medium without royalty provided the copyright
  notice and this notice are preserved.
*/


struct _cop_ {unichar code; unsigned char cop;};

static const unsigned int uni_cop_table_size = 355;
static struct _cop_ uni_cop_table[]=
{
  {0x0300,230},
  {0x0301,230},
  {0x0302,230},
  {0x0303,230},
  {0x0304,230},
  {0x0305,230},
  {0x0306,230},
  {0x0307,230},
  {0x0308,230},
  {0x0309,230},
  {0x030A,230},
  {0x030B,230},
  {0x030C,230},
  {0x030D,230},
  {0x030E,230},
  {0x030F,230},
  {0x0310,230},
  {0x0311,230},
  {0x0312,230},
  {0x0313,230},
  {0x0314,230},
  {0x0315,232},
  {0x0316,220},
  {0x0317,220},
  {0x0318,220},
  {0x0319,220},
  {0x031A,232},
  {0x031B,216},
  {0x031C,220},
  {0x031D,220},
  {0x031E,220},
  {0x031F,220},
  {0x0320,220},
  {0x0321,202},
  {0x0322,202},
  {0x0323,220},
  {0x0324,220},
  {0x0325,220},
  {0x0326,220},
  {0x0327,202},
  {0x0328,202},
  {0x0329,220},
  {0x032A,220},
  {0x032B,220},
  {0x032C,220},
  {0x032D,220},
  {0x032E,220},
  {0x032F,220},
  {0x0330,220},
  {0x0331,220},
  {0x0332,220},
  {0x0333,220},
  {0x0334,1},
  {0x0335,1},
  {0x0336,1},
  {0x0337,1},
  {0x0338,1},
  {0x0339,220},
  {0x033A,220},
  {0x033B,220},
  {0x033C,220},
  {0x033D,230},
  {0x033E,230},
  {0x033F,230},
  {0x0340,230},
  {0x0341,230},
  {0x0342,230},
  {0x0343,230},
  {0x0344,230},
  {0x0345,220},
  {0x0360,234},
  {0x0361,234},
  {0x0483,230},
  {0x0484,230},
  {0x0485,230},
  {0x0486,230},
  {0x0591,220},
  {0x0592,230},
  {0x0593,230},
  {0x0594,230},
  {0x0595,230},
  {0x0596,220},
  {0x0597,230},
  {0x0598,230},
  {0x0599,230},
  {0x059A,222},
  {0x059B,220},
  {0x059C,230},
  {0x059D,230},
  {0x059E,230},
  {0x059F,230},
  {0x05A0,230},
  {0x05A1,230},
  {0x05A3,220},
  {0x05A4,220},
  {0x05A5,220},
  {0x05A6,220},
  {0x05A7,220},
  {0x05A8,230},
  {0x05A9,230},
  {0x05AA,220},
  {0x05AB,230},
  {0x05AC,230},
  {0x05AD,222},
  {0x05AE,230},
  {0x05AF,230},
  {0x05B0,10},
  {0x05B1,11},
  {0x05B2,12},
  {0x05B3,13},
  {0x05B4,14},
  {0x05B5,15},
  {0x05B6,16},
  {0x05B7,17},
  {0x05B8,18},
  {0x05B9,19},
  {0x05BB,20},
  {0x05BC,21},
  {0x05BD,22},
  {0x05BF,23},
  {0x05C1,24},
  {0x05C2,25},
  {0x05C4,230},
  {0x064B,27},
  {0x064C,28},
  {0x064D,29},
  {0x064E,30},
  {0x064F,31},
  {0x0650,32},
  {0x0651,33},
  {0x0652,34},
  {0x0670,35},
  {0x06D6,230},
  {0x06D7,230},
  {0x06D8,230},
  {0x06D9,230},
  {0x06DA,230},
  {0x06DB,230},
  {0x06DC,230},
  {0x06DF,230},
  {0x06E0,230},
  {0x06E1,230},
  {0x06E2,230},
  {0x06E3,220},
  {0x06E4,230},
  {0x06E7,230},
  {0x06E8,230},
  {0x06EA,220},
  {0x06EB,230},
  {0x06EC,230},
  {0x06ED,220},
  {0x0901,37},
  {0x0902,36},
  {0x093C,7},
  {0x0941,38},
  {0x0942,39},
  {0x0943,40},
  {0x0944,41},
  {0x0945,42},
  {0x0946,43},
  {0x0947,44},
  {0x0948,45},
  {0x094D,9},
  {0x0951,46},
  {0x0952,47},
  {0x0953,230},
  {0x0954,230},
  {0x0962,48},
  {0x0963,49},
  {0x0981,50},
  {0x09BC,7},
  {0x09C1,51},
  {0x09C2,52},
  {0x09C3,53},
  {0x09C4,54},
  {0x09CD,9},
  {0x09E2,55},
  {0x09E3,56},
  {0x0A02,57},
  {0x0A3C,7},
  {0x0A41,58},
  {0x0A42,59},
  {0x0A47,60},
  {0x0A48,61},
  {0x0A4B,62},
  {0x0A4C,63},
  {0x0A4D,9},
  {0x0A70,64},
  {0x0A71,65},
  {0x0A81,67},
  {0x0A82,66},
  {0x0ABC,7},
  {0x0AC1,68},
  {0x0AC2,69},
  {0x0AC3,70},
  {0x0AC4,71},
  {0x0AC5,72},
  {0x0AC7,73},
  {0x0AC8,74},
  {0x0ACD,9},
  {0x0B01,75},
  {0x0B3C,7},
  {0x0B3F,76},
  {0x0B41,77},
  {0x0B42,78},
  {0x0B43,79},
  {0x0B4D,9},
  {0x0B56,230},
  {0x0BC0,80},
  {0x0BCD,9},
  {0x0C3E,81},
  {0x0C3F,82},
  {0x0C40,83},
  {0x0C46,84},
  {0x0C47,85},
  {0x0C48,86},
  {0x0C4A,87},
  {0x0C4B,88},
  {0x0C4C,89},
  {0x0C4D,9},
  {0x0C55,90},
  {0x0C56,91},
  {0x0CBF,92},
  {0x0CC6,93},
  {0x0CCC,94},
  {0x0CCD,9},
  {0x0D41,95},
  {0x0D42,96},
  {0x0D43,97},
  {0x0D4D,9},
  {0x0E31,98},
  {0x0E34,99},
  {0x0E35,100},
  {0x0E36,101},
  {0x0E37,102},
  {0x0E38,103},
  {0x0E39,104},
  {0x0E3A,105},
  {0x0E47,106},
  {0x0E48,107},
  {0x0E49,108},
  {0x0E4A,109},
  {0x0E4B,110},
  {0x0E4C,111},
  {0x0E4D,112},
  {0x0E4E,128},
  {0x0EB1,113},
  {0x0EB4,114},
  {0x0EB5,115},
  {0x0EB6,116},
  {0x0EB7,117},
  {0x0EB8,118},
  {0x0EB9,119},
  {0x0EBB,120},
  {0x0EBC,121},
  {0x0EC8,122},
  {0x0EC9,123},
  {0x0ECA,124},
  {0x0ECB,125},
  {0x0ECC,126},
  {0x0ECD,127},
  {0x0F18,220},
  {0x0F19,220},
  {0x0F35,230},
  {0x0F37,230},
  {0x0F39,216},
  {0x0F3E,220},
  {0x0F3F,220},
  {0x0F71,129},
  {0x0F72,130},
  {0x0F73,131},
  {0x0F74,132},
  {0x0F75,133},
  {0x0F76,134},
  {0x0F77,135},
  {0x0F78,136},
  {0x0F79,137},
  {0x0F7A,138},
  {0x0F7B,139},
  {0x0F7C,140},
  {0x0F7D,141},
  {0x0F7E,142},
  {0x0F80,143},
  {0x0F81,144},
  {0x0F82,230},
  {0x0F83,230},
  {0x0F84,9},
  {0x0F86,230},
  {0x0F87,230},
  {0x0F88,230},
  {0x0F89,230},
  {0x0F8A,230},
  {0x0F8B,230},
  {0x0F90,6},
  {0x0F91,6},
  {0x0F92,6},
  {0x0F93,6},
  {0x0F94,6},
  {0x0F95,6},
  {0x0F97,6},
  {0x0F99,6},
  {0x0F9A,6},
  {0x0F9B,6},
  {0x0F9C,6},
  {0x0F9D,6},
  {0x0F9E,6},
  {0x0F9F,6},
  {0x0FA0,6},
  {0x0FA1,6},
  {0x0FA2,6},
  {0x0FA3,6},
  {0x0FA4,6},
  {0x0FA5,6},
  {0x0FA6,6},
  {0x0FA7,6},
  {0x0FA8,6},
  {0x0FA9,6},
  {0x0FAA,6},
  {0x0FAB,6},
  {0x0FAC,6},
  {0x0FAD,6},
  {0x0FB1,6},
  {0x0FB2,6},
  {0x0FB3,6},
  {0x0FB4,6},
  {0x0FB5,6},
  {0x0FB6,6},
  {0x0FB7,6},
  {0x0FB9,6},
  {0x20D0,230},
  {0x20D1,230},
  {0x20D2,1},
  {0x20D3,1},
  {0x20D4,230},
  {0x20D5,230},
  {0x20D6,230},
  {0x20D7,230},
  {0x20D8,1},
  {0x20D9,1},
  {0x20DA,1},
  {0x20DB,230},
  {0x20DC,230},
  {0x20E1,1},
  {0x302A,218},
  {0x302B,228},
  {0x302C,232},
  {0x302D,222},
  {0x302E,224},
  {0x302F,224},
  {0x3099,8},
  {0x309A,8},
  {0xFB1E,26},
  {0xFE20,230},
  {0xFE21,230},
  {0xFE22,230},
  {0xFE23,230},
};

==> gnustep-base_1.26.0.orig.tar.gz: gnustep-base-1.26.0/Source/Additions/unicode/cop.h <==
/* COP table
 * This records diacriticals and their copmbining class
 * FIXME ... needs updating to latest unicode
 */
/*
  Copyright (C) 2005 Free Software Foundation

  Copying and distribution of this file, with or without modification,
  are permitted in any medium without royalty provided the copyright
  notice and this notice are preserved.
*/


struct _cop_ {unichar code; unsigned char cop;};

static struct _cop_ uni_cop_table[]=
{
  {0x0300,230},
  {0x0301,230},
  {0x0302,230},
  {0x0303,230},
  {0x0304,230},
  {0x0305,230},
  {0x0306,230},
  {0x0307,230},
  {0x0308,230},
  {0x0309,230},
  {0x030A,230},
  {0x030B,230},
  {0x030C,230},
  {0x030D,230},
  {0x030E,230},
  {0x030F,230},
  {0x0310,230},
  {0x0311,230},
  {0x0312,230},
  {0x0313,230},
  {0x0314,230},
  {0x0315,232},
  {0x0316,220},
  {0x0317,220},
  {0x0318,220},
  {0x0319,220},
  {0x031A,232},
  {0x031B,216},
  {0x031C,220},
  {0x031D,220},
  {0x031E,220},
  {0x031F,220},
  {0x0320,220},
  {0x0321,202},
  {0x0322,202},
  {0x0323,220},
  {0x0324,220},
  {0x0325,220},
  {0x0326,220},
  {0x0327,202},
  {0x0328,202},
  {0x0329,220},
  {0x032A,220},
  {0x032B,220},
  {0x032C,220},
  {0x032D,220},
  {0x032E,220},
  {0x032F,220},
  {0x0330,220},
  {0x0331,220},
  {0x0332,220},
  {0x0333,220},
  {0x0334,1},
  {0x0335,1},
  {0x0336,1},
  {0x0337,1},
  {0x0338,1},
  {0x0339,220},
  {0x033A,220},
  {0x033B,220},
  {0x033C,220},
  {0x033D,230},
  {0x033E,230},
  {0x033F,230},
  {0x0340,230},
  {0x0341,230},
  {0x0342,230},
  {0x0343,230},
  {0x0344,230},
  {0x0345,220},
  {0x0360,234},
  {0x0361,234},
  {0x0483,230},
  {0x0484,230},
  {0x0485,230},
  {0x0486,230},
  {0x0591,220},
  {0x0592,230},
  {0x0593,230},
  {0x0594,230},
  {0x0595,230},
  {0x0596,220},
  {0x0597,230},
  {0x0598,230},
  {0x0599,230},
  {0x059A,222},
  {0x059B,220},
  {0x059C,230},
  {0x059D,230},
  {0x059E,230},
  {0x059F,230},
  {0x05A0,230},
  {0x05A1,230},
  {0x05A3,220},
  {0x05A4,220},
  {0x05A5,220},
  {0x05A6,220},
  {0x05A7,220},
  {0x05A8,230},
  {0x05A9,230},
  {0x05AA,220},
  {0x05AB,230},
  {0x05AC,230},
  {0x05AD,222},
  {0x05AE,230},
  {0x05AF,230},
  {0x05B0,10},
  {0x05B1,11},
  {0x05B2,12},
  {0x05B3,13},
  {0x05B4,14},
  {0x05B5,15},
  {0x05B6,16},
  {0x05B7,17},
  {0x05B8,18},
  {0x05B9,19},
  {0x05BB,20},
  {0x05BC,21},
  {0x05BD,22},
  {0x05BF,23},
  {0x05C1,24},
  {0x05C2,25},
  {0x05C4,230},
  {0x064B,27},
  {0x064C,28},
  {0x064D,29},
  {0x064E,30},
  {0x064F,31},
  {0x0650,32},
  {0x0651,33},
  {0x0652,34},
  {0x0670,35},
  {0x06D6,230},
  {0x06D7,230},
  {0x06D8,230},
  {0x06D9,230},
  {0x06DA,230},
  {0x06DB,230},
  {0x06DC,230},
  {0x06DF,230},
  {0x06E0,230},
  {0x06E1,230},
  {0x06E2,230},
  {0x06E3,220},
  {0x06E4,230},
  {0x06E7,230},
  {0x06E8,230},
  {0x06EA,220},
  {0x06EB,230},
  {0x06EC,230},
  {0x06ED,220},
  {0x0901,37},
  {0x0902,36},
  {0x093C,7},
  {0x0941,38},
  {0x0942,39},
  {0x0943,40},
  {0x0944,41},
  {0x0945,42},
  {0x0946,43},
  {0x0947,44},
  {0x0948,45},
  {0x094D,9},
  {0x0951,46},
  {0x0952,47},
  {0x0953,230},
  {0x0954,230},
  {0x0962,48},
  {0x0963,49},
  {0x0981,50},
  {0x09BC,7},
  {0x09C1,51},
  {0x09C2,52},
  {0x09C3,53},
  {0x09C4,54},
  {0x09CD,9},
  {0x09E2,55},
  {0x09E3,56},
  {0x0A02,57},
  {0x0A3C,7},
  {0x0A41,58},
  {0x0A42,59},
  {0x0A47,60},
  {0x0A48,61},
  {0x0A4B,62},
  {0x0A4C,63},
  {0x0A4D,9},
  {0x0A70,64},
  {0x0A71,65},
  {0x0A81,67},
  {0x0A82,66},
  {0x0ABC,7},
  {0x0AC1,68},
  {0x0AC2,69},
  {0x0AC3,70},
  {0x0AC4,71},
  {0x0AC5,72},
  {0x0AC7,73},
  {0x0AC8,74},
  {0x0ACD,9},
  {0x0B01,75},
  {0x0B3C,7},
  {0x0B3F,76},
  {0x0B41,77},
  {0x0B42,78},
  {0x0B43,79},
  {0x0B4D,9},
  {0x0B56,230},
  {0x0BC0,80},
  {0x0BCD,9},
  {0x0C3E,81},
  {0x0C3F,82},
  {0x0C40,83},
  {0x0C46,84},
  {0x0C47,85},
  {0x0C48,86},
  {0x0C4A,87},
  {0x0C4B,88},
  {0x0C4C,89},
  {0x0C4D,9},
  {0x0C55,90},
  {0x0C56,91},
  {0x0CBF,92},
  {0x0CC6,93},
  {0x0CCC,94},
  {0x0CCD,9},
  {0x0D41,95},
  {0x0D42,96},
  {0x0D43,97},
  {0x0D4D,9},
  {0x0E31,98},
  {0x0E34,99},
  {0x0E35,100},
  {0x0E36,101},
  {0x0E37,102},
  {0x0E38,103},
  {0x0E39,104},
  {0x0E3A,105},
  {0x0E47,106},
  {0x0E48,107},
  {0x0E49,108},
  {0x0E4A,109},
  {0x0E4B,110},
  {0x0E4C,111},
  {0x0E4D,112},
  {0x0E4E,128},
  {0x0EB1,113},
  {0x0EB4,114},
  {0x0EB5,115},
  {0x0EB6,116},
  {0x0EB7,117},
  {0x0EB8,118},
  {0x0EB9,119},
  {0x0EBB,120},
  {0x0EBC,121},
  {0x0EC8,122},
  {0x0EC9,123},
  {0x0ECA,124},
  {0x0ECB,125},
  {0x0ECC,126},
  {0x0ECD,127},
  {0x0F18,220},
  {0x0F19,220},
  {0x0F35,230},
  {0x0F37,230},
  {0x0F39,216},
  {0x0F3E,220},
  {0x0F3F,220},
  {0x0F71,129},
  {0x0F72,130},
  {0x0F73,131},
  {0x0F74,132},
  {0x0F75,133},
  {0x0F76,134},
  {0x0F77,135},
  {0x0F78,136},
  {0x0F79,137},
  {0x0F7A,138},
  {0x0F7B,139},
  {0x0F7C,140},
  {0x0F7D,141},
  {0x0F7E,142},
  {0x0F80,143},
  {0x0F81,144},
  {0x0F82,230},
  {0x0F83,230},
  {0x0F84,9},
  {0x0F86,230},
  {0x0F87,230},
  {0x0F88,230},
  {0x0F89,230},
  {0x0F8A,230},
  {0x0F8B,230},
  {0x0F90,6},
  {0x0F91,6},
  {0x0F92,6},
  {0x0F93,6},
  {0x0F94,6},
  {0x0F95,6},
  {0x0F97,6},
  {0x0F99,6},
  {0x0F9A,6},
  {0x0F9B,6},
  {0x0F9C,6},
  {0x0F9D,6},
  {0x0F9E,6},
  {0x0F9F,6},
  {0x0FA0,6},
  {0x0FA1,6},
  {0x0FA2,6},
  {0x0FA3,6},
  {0x0FA4,6},
  {0x0FA5,6},
  {0x0FA6,6},
  {0x0FA7,6},
  {0x0FA8,6},
  {0x0FA9,6},
  {0x0FAA,6},
  {0x0FAB,6},
  {0x0FAC,6},
  {0x0FAD,6},
  {0x0FB1,6},
  {0x0FB2,6},
  {0x0FB3,6},
  {0x0FB4,6},
  {0x0FB5,6},
  {0x0FB6,6},
  {0x0FB7,6},
  {0x0FB9,6},
  {0x20D0,230},
  {0x20D1,230},
  {0x20D2,1},
  {0x20D3,1},
  {0x20D4,230},
  {0x20D5,230},
  {0x20D6,230},
  {0x20D7,230},
  {0x20D8,1},
  {0x20D9,1},
  {0x20DA,1},
  {0x20DB,230},
  {0x20DC,230},
  {0x20E1,1},
  {0x302A,218},
  {0x302B,228},
  {0x302C,232},
  {0x302D,222},
  {0x302E,224},
  {0x302F,224},
  {0x3099,8},
  {0x309A,8},
  {0xFB1E,26},
  {0xFE20,230},
  {0xFE21,230},
  {0xFE22,230},
  {0xFE23,230},
};
static const unsigned int
uni_cop_table_size = sizeof(uni_cop_table) / sizeof(struct _cop_);
